from flask import Flask, jsonify
from pymongo import MongoClient
from pymongo.server_api import ServerApi
from consts import DB_NAME, COLLECTION, MONGO_URI, MONGO_CERT_PATH
import os


app = Flask(__name__)

# Create MongoDB connection
try:
    client = MongoClient(MONGO_URI,
                         tls=True,
                         tlsCertificateKeyFile=MONGO_CERT_PATH,
                         server_api=ServerApi('1'))

    db = client[DB_NAME]
    collection = db[COLLECTION]
    print("Connected to MongoDB")

except Exception as e:
    print(f"Failed to connect to MongoDB: {e}")


# Start a server on port 8443
if __name__ == "__main__": # NB currently using test key
    print("Starting server on port 8443")
    try:
        current_directory = os.getcwd()
        print("Current Working Directory:", current_directory)

        app.run(port=8443, ssl_context=('server/certificates/testCert.crt', 'server/certificates/testKey.key'))
        print("Server running on port 8443")
    except Exception as e:
        print(f"Failed to start server on port 8443: {e}")


# Default path
@app.route('/')
def default():
    print("Default path hit!")
